'use strict';

module.exports = function(grunt) {
    require('load-grunt-tasks')(grunt);
    require('time-grunt')(grunt);

    // Options
    var options = {
        accountant: {
            frontend: {
                app: require('./bower.json'),
                src: 'accountant-ui',
                dist: 'accountant-ui_dist'
            }
        },

        config: {
            src: 'grunt-config/*.js'
        },
        pkg: grunt.file.readJSON('package.json'),
        banner: '/*! <%= pkg.name %> <%= grunt.template.today("dd-mm-yyyy") %>\n' +
          '* Copyright (c) <%= grunt.template.today("yyyy") %> <%= pkg.author %> */\n'
    };

    var configs = require('load-grunt-configs')(grunt, options);
    grunt.initConfig(configs);

    grunt.registerTask('dependencies', [
        'shell:npmInstall',
        'shell:bowerInstall',
        'shell:pipInstall',
        'wiredep:app'
    ]);

    grunt.registerTask('pydev', [
        'newer:flake8'
    ]);

    grunt.registerTask('jsdev', [
        'wiredep',
        'newer:eslint'
    ]);

    grunt.registerTask('htmldev', [
        'newer:htmllint'
    ]);

    grunt.registerTask('dev', [
        'dependencies',
        'pydev',
        'jsdev',
        'htmldev'
    ]);

    grunt.registerTask('serve', [
        'dev',
        'bgShell:runserver',
        'connect:livereload',
        'watch'
    ]);

    grunt.registerTask('dist', [
        'wiredep',
        'clean:dist',
        'useminPrepare',
        'copy:dist',
        'copy:styles',
        'cssmin:generated',
        'concat:generated',
        'ngAnnotate',
        'uglify:generated',
        'filerev',
        'usemin'
    ]);
};
